@@ -1,5 +1,5 @@
-; ACL2 Version 6.3 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2013, Regents of the University of Texas
+; ACL2 Version 6.4 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2014, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -16,7 +16,7 @@
 ; email:       Kaufmann@cs.utexas.edu      and Moore@cs.utexas.edu
 ; Department of Computer Science
 ; University of Texas at Austin
-; Austin, TX 78701 U.S.A.
+; Austin, TX 78712 U.S.A.
 
 (in-package "ACL2")
 
@@ -439,6 +439,14 @@
     'character)
    ((atom form)
     t)
+   ((eq (car form) 'return-last)
+    (cond ((equal (cadr form) ''mbe1-raw)
+           (output-type-for-declare-form-rec (caddr form) flet-alist))
+          ((and (equal (cadr form) ''progn)
+                (consp (caddr form))
+                (eq (car (caddr form)) 'throw-nonexec-error))
+           (setq *acl2-output-type-abort* '*))
+          (t (output-type-for-declare-form-rec (car (last form)) flet-alist))))
    ((member (car form) '(return-last return-from when)
             :test 'eq)
     (output-type-for-declare-form-rec (car (last form)) flet-alist))
@@ -531,6 +539,7 @@
    ((member (car form)
             '(tagbody ; e.g., ld-fn
               throw-raw-ev-fncall ; e.g., from defchoose
+              throw-nonexec-error
               eval
               error
               )
@@ -585,8 +594,8 @@
 ; We return a list of output types, one per value.  So if #-acl2-mv-as-values,
 ; then we always return a list of length one.
 
-  (when (eq fn 'return-last)
-    (return-from output-type-for-declare-form '*))
+  #-acl2-mv-as-values
+  (declare (ignore fn))
   #-acl2-mv-as-values
   (let* ((*acl2-output-type-abort* nil) ; protect for call on next line
          (result (output-type-for-declare-form-rec form nil)))
@@ -927,9 +936,10 @@ notation causes an error and (b) the use of ,. is not permitted."
 ; it didn't, surely different lisps will define char-name differently.  So,
 ; we can't allow notation such as #\\346.
 
-  (let ((ch (read-char s)))
-    (cond ((member ch *acl2-read-character-terminators*)
-           (unread-char ch s)
+  (let* ((ch (read-char s nil nil)))
+    (cond ((or (null ch)
+               (member ch *acl2-read-character-terminators*))
+           (when ch (unread-char ch s))
            (cond
             ((characterp acc)
              acc)
@@ -1411,7 +1421,11 @@ notation causes an error and (b) the use of ,. is not permitted."
                      "Unable to obtain the truename of file ~x0.~@1"
                      filename
                      (if (qfuncall msgp namestringp)
-                         (qfuncall msg "  ~@0" namestringp)
+
+; It is tempting to write (qfuncall msg "  ~@0" namestringp) just below, but
+; msg is a macro, so we construct the appropriate message ourselves.
+
+                         (list "  ~@0" (cons #\0 namestringp))
                        "")))))
           (t (namestring truename)))))
 
