@@ -1,5 +1,5 @@
-; ACL2 Version 6.3 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2013, Regents of the University of Texas
+; ACL2 Version 6.4 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2014, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -16,7 +16,7 @@
 ; email:       Kaufmann@cs.utexas.edu      and Moore@cs.utexas.edu
 ; Department of Computer Science
 ; University of Texas at Austin
-; Austin, TX 78701 U.S.A.
+; Austin, TX 78712 U.S.A.
 
 ; This file cannot be compiled because it changes packages in the middle.
 
@@ -432,23 +432,6 @@ implementations.")
   #-(or gcl lispworks allegro cmu sbcl clisp ccl)
   (error "SYSTEM-CALL is not yet defined in this Lisp."))
 
-(defun copy-acl2 (dir)
-  (system-call
-   "cp"
-   (append '("makefile"
-             "acl2.lisp"
-             "acl2-check.lisp"
-             "acl2-fns.lisp"
-             "init.lisp"
-             "acl2-init.lisp")
-           (append (let ((result (list (format nil "~a" dir))))
-                     (dolist
-                      (x *acl2-files*)
-                      (setq result
-                            (cons (format nil "~a.lisp" x)
-                                  result)))
-                     result)))))
-
 (defun our-probe-file (filename)
 
 ; Use this function instead of probe-file if filename might be a directory.
@@ -666,9 +649,13 @@ implementations.")
                                    (let ((result nil))
                                      (dolist
                                        (x *acl2-files*)
-                                       (setq result
-                                             (cons (format nil fmt-str x)
-                                                   result)))
+
+; Since we don't want to edit doc.lisp, don't go there with tags.
+
+                                       (when (not (equal x "doc.lisp"))
+                                         (setq result
+                                               (cons (format nil fmt-str x)
+                                                     result))))
                                      (reverse result)))))
 
 ; We want to be sure to include the *-raw.lisp files even if we are not
@@ -727,7 +714,7 @@ implementations.")
   (concatenate
    'string
    "~% ~a built ~a.~
-    ~% Copyright (C) 2013, Regents of the University of Texas"
+    ~% Copyright (C) 2014, Regents of the University of Texas"
    "~% ACL2 comes with ABSOLUTELY NO WARRANTY.  This is free software and you~
     ~% are welcome to redistribute it under certain conditions.  For details,~
     ~% see the LICENSE file distributed with ACL2.~%"
@@ -873,7 +860,8 @@ implementations.")
 ; form.
 
     (dolist (fl *acl2-files*)
-      (proclaim-file (format nil "~a.lisp" fl) str))
+      (when (not (equal fl "doc.lisp")) ; no need to proclaim that one!
+        (proclaim-file (format nil "~a.lisp" fl) str)))
     (when str ; equivalently, when outfilename is non-nil
       (close str))))
 
