@@ -1,5 +1,5 @@
-; ACL2 Version 6.3 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2013, Regents of the University of Texas
+; ACL2 Version 6.4 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2014, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -16,7 +16,7 @@
 ; email:       Kaufmann@cs.utexas.edu      and Moore@cs.utexas.edu
 ; Department of Computer Science
 ; University of Texas at Austin
-; Austin, TX 78701 U.S.A.
+; Austin, TX 78712 U.S.A.
 
 ; This file, defpkgs.lisp, illustrates the idea that defpkg forms
 ; should be off in files all by themselves.  We require defpkg forms
@@ -90,7 +90,8 @@
         ACL2-ORACLE ACL2-OUTPUT-CHANNEL-PACKAGE
         ACL2-PACKAGE ACONS ACTIVE-RUNEP
         ADD-BINOP ADD-CUSTOM-KEYWORD-HINT
-        ADD-DEFAULT-HINTS ADD-DEFAULT-HINTS! ADD-INCLUDE-BOOK-DIR
+        ADD-DEFAULT-HINTS ADD-DEFAULT-HINTS!
+        ADD-INCLUDE-BOOK-DIR ADD-INCLUDE-BOOK-DIR!
         ADD-INVISIBLE-FNS ADD-LD-KEYWORD-ALIAS ADD-LD-KEYWORD-ALIAS!
         ADD-MACRO-ALIAS ADD-MACRO-FN
         ADD-MATCH-FREE-OVERRIDE ADD-NTH-ALIAS
@@ -223,7 +224,7 @@
         DEFTHM DEFTHMD DEFTTAG DEFUN DEFUN-INLINE DEFUN-NOTINLINE DEFUN-NX
         DEFUN-SK DEFUND DEFUND-INLINE DEFUND-NOTINLINE DEFUND-NX DEFUNS
         DELETE-ASSOC DELETE-ASSOC-EQ DELETE-ASSOC-EQUAL
-        DELETE-INCLUDE-BOOK-DIR
+        DELETE-INCLUDE-BOOK-DIR DELETE-INCLUDE-BOOK-DIR!
         DENOMINATOR DIGIT-CHAR-P DIGIT-TO-CHAR
         DIMENSIONS DISABLE DISABLE-FORCING
         DISABLE-IMMEDIATE-FORCE-MODEP
@@ -637,42 +638,4 @@ acl2:: prefix."
 
 (defpkg "ACL2-USER"
   (union-eq *acl2-exports*
-            *common-lisp-symbols-from-main-lisp-package*)
-
-  ":Doc-Section ACL2::Programming
-
-  a package the ACL2 user may prefer~/
-
-  This package imports the standard Common Lisp symbols that ACL2
-  supports and also a few symbols from package ~c[\"ACL2\"] that are
-  commonly used when interacting with ACL2.  You may prefer to select
-  this as your current package so as to avoid colliding with ACL2
-  system names.~/
-
-  This package imports the symbols listed in
-  ~c[*common-lisp-symbols-from-main-lisp-package*], which contains
-  hundreds of CLTL function and macro names including those supported
-  by ACL2 such as ~ilc[cons], ~ilc[car], and ~ilc[cdr].  It also imports the symbols in
-  ~c[*acl2-exports*], which contains a few symbols that are frequently
-  used while interacting with the ACL2 system, such as ~ilc[implies],
-  ~ilc[defthm], and ~ilc[rewrite].  It imports nothing else.
-
-  Thus, names such as ~ilc[alistp], ~ilc[member-equal], and ~ilc[type-set], which are
-  defined in the ~c[\"ACL2\"] package are not present here.  If you find
-  yourself frequently colliding with names that are defined in
-  ~c[\"ACL2\"] you might consider selecting ~c[\"ACL2-USER\"] as your current
-  package (~pl[in-package]).  If you select ~c[\"ACL2-USER\"] as the
-  current package, you may then simply type ~ilc[member-equal] to refer to
-  ~c[acl2-user::member-equal], which you may define as you see fit.  Of
-  course, should you desire to refer to the ~c[\"ACL2\"] version of
-  ~ilc[member-equal], you will have to use the ~c[\"ACL2::\"] prefix, e.g.,
-  ~c[acl2::member-equal].
-
-  If, while using ~c[\"ACL2-USER\"] as the current package, you find that
-  there are symbols from ~c[\"ACL2\"] that you wish we had imported into
-  it (because they are frequently used in interaction), please bring
-  those symbols to our attention.  For example, should ~ilc[union-theories]
-  and ~ilc[universal-theory] be imported?  Except for stabilizing on the
-  ``frequently used'' names from ~c[\"ACL2\"], we intend never to define a
-  symbol whose ~ilc[symbol-package-name] is ~c[\"ACL2-USER\"].")
-
+            *common-lisp-symbols-from-main-lisp-package*))
