@@ -1,4 +1,4 @@
-; ACL2 Version 6.3 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 6.4 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2013, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -116,7 +116,10 @@
   ;      subexpression.  See ACL2 documentation for PROOF-CHECKER.
   ; "control-t control-d" is like "control-t d" above, but for DIVE instead
   ;      (used with "pp" instead of "p")
-; Support for Dynamic Monitoring of Rewrites (dmr)
+; Load other tools
+  ; Support for Dynamic Monitoring of Rewrites (dmr)
+  ; Support for ACL2-Doc browser
+  ; Support for xdoc-link-mode, used by acl2+books XDOC manual
 ; Miscellaneous
   ; "meta-x acl2-info" brings up ACL2 documentation in pleasant emacs-info
   ;      format.
@@ -160,16 +163,18 @@
 (defvar *acl2-sources-dir*)
 
 ; Attempt to set *acl2-sources-dir*.
+; WARNING: If you change this form, then also change the same form in
+; acl2-doc.el.
 (if (and (not (boundp '*acl2-sources-dir*))
-	 (file-name-absolute-p load-file-name))
+         (file-name-absolute-p load-file-name))
     (let ((pattern (if (string-match "[\\]" load-file-name)
-		       "\[^\\]+\\*$"
-		     "/[^/]+/*$"))
-	  (dir (file-name-directory load-file-name)))
+                       "\[^\\]+\\*$"
+                     "/[^/]+/*$"))
+          (dir (file-name-directory load-file-name)))
       (let ((posn (string-match pattern dir)))
-	(if posn
-	    (setq *acl2-sources-dir*
-		  (substring dir 0 (1+ posn)))))))
+        (if posn
+            (setq *acl2-sources-dir*
+                  (substring dir 0 (1+ posn)))))))
 
 ; The following causes, for every event, the event name to be given
 ; the same color (in font-lock mode) as when defun is called.  If you
@@ -179,14 +184,14 @@
 
 (font-lock-add-keywords
  'lisp-mode
- '(("\\((def[^ \t]*\\|(encapsulate\\|(in-theory\\|(include-book\\|(local\\)\\>"
-    . font-lock-keyword-face)
-   ("\\((make-event\\|(mutual-recursion\\|(prog[^ \t]*\\)\\>"
-    . font-lock-keyword-face)
-   ("\\((table\\|(theory-invariant\\)\\>"
-    . font-lock-keyword-face)
-   ("\\((value-triple\\|(verify-guards\\|(verify-termination\\)\\>"
-    . font-lock-keyword-face)))
+ '(("(\\(def[^ \t]*\\|encapsulate\\|in-theory\\|include-book\\|local\\)\\>"
+    . 1)
+   ("(\\(make-event\\|mutual-recursion\\|prog[^ \t]*\\)\\>"
+    . 1)
+   ("(\\(table\\|theory-invariant\\)\\>"
+    . 1)
+   ("(\\(value-triple\\|verify-guards\\|verify-termination\\)\\>"
+    . 1)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Control-t keymap
@@ -194,6 +199,9 @@
 
 (when (not (boundp 'ctl-t-keymap))
 
+; Warning: Keep this in sync with the introduction of ctl-t-keymap in
+; acl2-doc.el.
+
 ; This trick probably came from Bob Boyer, to define a new keymap; so now
 ; control-t is the first character of a complex command.
   (defvar ctl-t-keymap)
@@ -896,11 +904,20 @@ of the current s-expression in the enclosing list"
     n))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;; Support for Dynamic Monitoring of Rewrites (dmr)
+;;; Load other tools
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+; Support for Dynamic Monitoring of Rewrites (dmr)
 (load (concat (acl2-sources-dir) "emacs/monitor.el"))
 
+; Support for ACL2-Doc browser
+(load (concat (acl2-sources-dir) "emacs/acl2-doc.el"))
+
+; Support for xdoc-link-mode, used by acl2+books XDOC manual
+(let ((xdoc-el-file (concat (acl2-sources-dir) "books/xdoc/xdoc.el")))
+  (if (file-exists-p xdoc-el-file)
+      (load xdoc-el-file)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Miscellaneous
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
